==> 0.0.5.tar.gz: aretmis_cupps_runner/lib/screens/bt_device_screen.dart <==
import 'package:flutter/material.dart';
import 'package:artemis_cupps/artemis_cupps.dart';

import '../data.dart';

class BtDeviceScreen extends StatefulWidget {
  final BtDevice device;

  const BtDeviceScreen({required this.device, Key? key}) : super(key: key);

  @override
  _BtDeviceScreenState createState() => _BtDeviceScreenState();
}

class _BtDeviceScreenState extends State<BtDeviceScreen> {
  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    BtDevice device =  widget.device;
    return Scaffold(
      appBar: AppBar(
        title: Text("${device.deviceIndex} ${device.deviceName}"),
        actions: [IconButton(onPressed: (){
          device.refreshStatus();
        }, icon:const Icon(Icons.refresh))],
      ),
      body: Container(
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
        child: Column(
          children: [
            Row(
              children: [
                Expanded(flex: 1, child: Image.asset(device.deviceParameter.status.image)),
                const SizedBox(width: 12),
                Expanded(
                    flex: 2,
                    child: Column(
                      children: [
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Status"),
                            Text(
                              "${device.deviceParameter.status}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Address"),
                            Text(
                              "${device.deviceParameter.ipAndPort}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [const Text("TCP Connection"), Icon(Icons.circle, color: device.isConnected ? Colors.green : Colors.red, size: 14)],
                        ),
                      ],
                    ))
              ],
            ),
            Row(
              children: [
                const Text("Available Modes"),
                const SizedBox(width: 12),
                Expanded(
                  child: Wrap(
                    direction: Axis.horizontal,
                    children: device.supportedInterfaceModes.map((e) => OutlinedButton(onPressed: () {}, child: Text(e.mode))).toList(),
                  ),
                ),
              ],
            ),
            const Divider(),
            Column(
              children: [
                ElevatedButton(
                  onPressed: () {
                    device.setLogo(DataExample.logoText);
                  },
                  child: const Text("Set Logo"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.setPectab(DataExample.pectabText);
                  },
                  child: const Text("Set Pectab"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.printAEA(DataExample.btText);
                  },
                  child: const Text("Print BT Test"),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}

==> 0.0.34.tar.gz: aretmis_cupps_runner/lib/screens/bt_device_screen.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:artemis_cupps/artemis_cupps.dart';

import '../data.dart';

class BtDeviceScreen extends StatefulWidget {
  final BtDevice device;

  const BtDeviceScreen({required this.device, Key? key}) : super(key: key);

  @override
  _BtDeviceScreenState createState() => _BtDeviceScreenState();
}

class _BtDeviceScreenState extends State<BtDeviceScreen> {
  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    BtDevice device =  widget.device;
    return Scaffold(
      appBar: AppBar(
        title: Text("${device.deviceIndex} ${device.deviceName}"),
        actions: [IconButton(onPressed: (){
          device.refreshStatus();
        }, icon:const Icon(Icons.refresh))],
      ),
      body: Container(
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
        child: Column(
          children: [
            Row(
              children: [
                Expanded(flex: 1, child: Image.asset(device.deviceParameter.status.image)),
                const SizedBox(width: 12),
                Expanded(
                    flex: 2,
                    child: Column(
                      children: [
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Status"),
                            Text(
                              "${device.deviceParameter.status}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            const Text("Address"),
                            Text(
                              "${device.deviceParameter.ipAndPort}",
                              style: const TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        const Divider(),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [const Text("TCP Connection"), Icon(Icons.circle, color: device.isConnected ? Colors.green : Colors.red, size: 14)],
                        ),
                      ],
                    ))
              ],
            ),
            Row(
              children: [
                const Text("Available Modes"),
                const SizedBox(width: 12),
                Expanded(
                  child: Wrap(
                    direction: Axis.horizontal,
                    children: device.supportedInterfaceModes.map((e) => OutlinedButton(onPressed: () {}, child: Text(e.mode))).toList(),
                  ),
                ),
              ],
            ),
            const Divider(),
            Column(
              children: [
                ElevatedButton(
                  onPressed: () async {
                    final alRes  = await device.auth(airlineID: "001",font: "L");
                    log("$alRes");
                  },
                  child: const Text("Auth"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.setLogo(DataExample.logoText);
                  },
                  child: const Text("Set Logo"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.setPectab(DataExample.btPectabAbomis);
                  },
                  child: const Text("Set Pectab"),
                ),
                ElevatedButton(
                  onPressed: () {
                    device.printAEA(DataExample.btAbomis);
                  },
                  child: const Text("Print BT Test"),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
